==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-directorymenu/translations/directorymenu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="120"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Paramètrage du menu des répertoires</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Répertoire de base :</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Nom du répertoire de base</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="91"/>
        <source>Choose Base Directory</source>
        <translation>Choisir le répertoire de base</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Choose Icon</source>
        <translation>Choisir l&apos;icône</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Icônes (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>Directory Menu</source>
        <translation>Menu des répertoires</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Echec du chargement de l&apos;icône.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-directorymenu/translations/directorymenu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="120"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Paramétrage du menu des répertoires</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Répertoire de base :</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Nom du répertoire de base</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="91"/>
        <source>Choose Base Directory</source>
        <translation>Choisir le répertoire de base</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Choose Icon</source>
        <translation>Choisir l&apos;icône</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Icônes (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>Directory Menu</source>
        <translation>Menu des répertoires</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Une erreur s&apos;est produite lors du chargement de l&apos;icône.</translation>
    </message>
</context>
</TS>
